==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Members_List/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","E-mail");
define("_REALNAME","Jmno");
define("_FUNCTIONS","Funkce");
define("_PREVIOUS","Pedchoz strnka");
define("_MEMBERSLIST","Seznam uivatel");
define("_GREETINGS","Vtme naposledy zaregistrovanho uivatele:");
define("_SORTBY","Tdno podle:");
define("_MNICKNAME","pezdvky");
define("_MREALNAME","pravho jmna");
define("_MEMAIL","e-mailu");
define("_MURL","url");
define("_ONLINEREG","Registrovan uivatel, kte jsou online:");
define("_WEHAVE","Mme dosud");
define("_MREGISTERED","registrovanch uivatel. Momentln prohl strnku");
define("_MREGONLINE","uivatel(/).");
define("_REGSOFAR","registrovan uivatele.");
define("_USERSFOUND","uivatel pod");
define("_USERSSHOWN","ukzat uivatele");
define("_NOMEMBERS","Nikdo nen registrovn pod pezdvkou zanajc na");
define("_PAGES","Strnky");
define("_HOMEPAGE","Domovsk strnka");

?>

==> phpnuke-6.0.tgz: www/phpnuke/html/modules/Members_List/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","E-mail");
define("_REALNAME","Jmno");
define("_FUNCTIONS","Funkce");
define("_PREVIOUS","Pedchoz strnka");
define("_MEMBERSLIST","Seznam uivatel");
define("_GREETINGS","Vtme naposledy zaregistrovanho uivatele:");
define("_SORTBY","Tdno podle:");
define("_MNICKNAME","pezdvky");
define("_MREALNAME","pravho jmna");
define("_MEMAIL","e-mailu");
define("_MURL","url");
define("_ONLINEREG","Registrovan uivatel, kte jsou online:");
define("_WEHAVE","Mme dosud");
define("_MREGISTERED","registrovanch uivatel. Momentln prohl strnku");
define("_MREGONLINE","uivatel(/).");
define("_REGSOFAR","registrovan uivatele.");
define("_USERSFOUND","uivatel pod");
define("_USERSSHOWN","ukzat uivatele");
define("_NOMEMBERS","Nikdo nen registrovn pod pezdvkou zanajc na");
define("_PAGES","Strnky");
define("_HOMEPAGE","Domovsk strnka");

?>
